MinorErrorCode

Enum MinorErrorCode 

#[non_exhaustive]
pub enum MinorErrorCode {
Show 141 variants Alignment, AlreadyExists, AlreadyInit, BadFile, BadGroup, BadId, BadIter, BadMessage, BadRange, BadSelect, BadSize, BadType, BadValue, Callback, CanApply, CantAlloc, CantAppend, CantAttach, CantCancel, CantClean, CantClip, CantCloseFile, CantCloseObj, CantCompare, CantCompute, CantConvert, CantCopy, CantCork, CantCount, CantCreate, CantDec, CantDecode, CantDelete, CantDeleteFile, CantDepend, CantDirty, CantEncode, CantExpunge, CantExtend, CantFilter, CantFind, CantFlush, CantFree, CantGather, CantGc, CantGet, CantGetSize, CantInc, CantInit, CantIns, CantInsert, CantList, CantLoad, CantLock, CantLockFile, CantMarkClean, CantMarkDirty, CantMarkSerialized, CantMarkUnserialized, CantMerge, CantModify, CantMove, CantNext, CantNotify, CantOpenFile, CantOpenObj, CantOperate, CantPack, CantPin, CantProtect, CantPut, CantRecv, CantRedistribute, CantRegister, CantRelease, CantRemove, CantRename, CantReset, CantResize, CantRestore, CantRevive, CantSelect, CantSerialize, CantSet, CantShrink, CantSort, CantSplit, CantSwap, CantTag, CantUncork, CantUndepend, CantUnlock, CantUnlockFile, CantUnpin, CantUnprotect, CantUnserialize, CantUpdate, CantWait, CloseError, CompLen, DupClass, Exists, Fcntl, FileExists, FileOpen, InconsistentState, LinkCount, Logging, Mount, Mpi, MpiErrStr, NLinks, NoEncoder, NoFilter, NoIds, NoIndependent, NoSpace, NoneMinor, NotCached, NotFound, NotHdf5, NotRegistered, ObjOpen, OpenError, Overflow, Path, Protect, ReadError, SeekError, SetDisallowed, SetLocal, SysErrStr, System, Traverse, Truncated, Uninitialized, Unmount, Unsupported, Version, WriteError, Other(hid_t),
}
The minor error code of an HDF5 error frame.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Alignment

H5E_ALIGNMENT: Alignment error



AlreadyExists

H5E_ALREADYEXISTS: Object already exists



AlreadyInit

H5E_ALREADYINIT: Object already initialized



BadFile

H5E_BADFILE: Bad file ID accessed



BadGroup

H5E_BADGROUP: Unable to find ID group information



BadId

H5E_BADID (H5E_BADATOM in older HDF5): Unable to find ID information (already closed?)



BadIter

H5E_BADITER: Iteration failed



BadMessage

H5E_BADMESG: Unrecognized message



BadRange

H5E_BADRANGE: Out of range



BadSelect

H5E_BADSELECT: Invalid selection



BadSize

H5E_BADSIZE: Bad size for object



BadType

H5E_BADTYPE: Inappropriate type



BadValue

H5E_BADVALUE: Bad value



Callback

H5E_CALLBACK: Callback failed



CanApply

H5E_CANAPPLY: Error from filter ‘can apply’ callback



CantAlloc

H5E_CANTALLOC: Can’t allocate space



CantAppend

H5E_CANTAPPEND: Can’t append object



CantAttach

H5E_CANTATTACH: Can’t attach object



CantCancel

H5E_CANTCANCEL: Can’t cancel operation



CantClean

H5E_CANTCLEAN: Unable to mark metadata as clean



CantClip

H5E_CANTCLIP: Can’t clip hyperslab region



CantCloseFile

H5E_CANTCLOSEFILE: Unable to close file



CantCloseObj

H5E_CANTCLOSEOBJ: Can’t close object



CantCompare

H5E_CANTCOMPARE: Can’t compare objects



CantCompute

H5E_CANTCOMPUTE: Can’t compute value



CantConvert

H5E_CANTCONVERT: Can’t convert datatypes



CantCopy

H5E_CANTCOPY: Unable to copy object



CantCork

H5E_CANTCORK: Unable to cork an object



CantCount

H5E_CANTCOUNT: Can’t count elements



CantCreate

H5E_CANTCREATE: Unable to create file



CantDec

H5E_CANTDEC: Unable to decrement reference count



CantDecode

H5E_CANTDECODE: Unable to decode value



CantDelete

H5E_CANTDELETE: Can’t delete message



CantDeleteFile

H5E_CANTDELETEFILE: Unable to delete file



CantDepend

H5E_CANTDEPEND: Unable to create a flush dependency



CantDirty

H5E_CANTDIRTY: Unable to mark metadata as dirty



CantEncode

H5E_CANTENCODE: Unable to encode value



CantExpunge

H5E_CANTEXPUNGE: Unable to expunge a metadata cache entry



CantExtend

H5E_CANTEXTEND: Can’t extend heap’s space



CantFilter

H5E_CANTFILTER: Filter operation failed



CantFind

H5E_CANTFIND: Unable to check for record



CantFlush

H5E_CANTFLUSH: Unable to flush data from cache



CantFree

H5E_CANTFREE: Unable to free object



CantGather

H5E_CANTGATHER: Can’t gather data



CantGc

H5E_CANTGC: Unable to garbage collect



CantGet

H5E_CANTGET: Can’t get value



CantGetSize

H5E_CANTGETSIZE: Unable to compute size



CantInc

H5E_CANTINC: Unable to increment reference count



CantInit

H5E_CANTINIT: Unable to initialize object



CantIns

H5E_CANTINS: Unable to insert metadata into cache



CantInsert

H5E_CANTINSERT: Unable to insert object



CantList

H5E_CANTLIST: Unable to list node



CantLoad

H5E_CANTLOAD: Unable to load metadata into cache



CantLock

H5E_CANTLOCK: Unable to lock object



CantLockFile

H5E_CANTLOCKFILE: Unable to lock file



CantMarkClean

H5E_CANTMARKCLEAN: Unable to mark a pinned entry as clean



CantMarkDirty

H5E_CANTMARKDIRTY: Unable to mark a pinned entry as dirty



CantMarkSerialized

H5E_CANTMARKSERIALIZED: Unable to mark an entry as serialized



CantMarkUnserialized

H5E_CANTMARKUNSERIALIZED: Unable to mark an entry as unserialized



CantMerge

H5E_CANTMERGE: Can’t merge objects



CantModify

H5E_CANTMODIFY: Unable to modify record



CantMove

H5E_CANTMOVE: Can’t move object



CantNext

H5E_CANTNEXT: Can’t move to next iterator location



CantNotify

H5E_CANTNOTIFY: Unable to notify object about action



CantOpenFile

H5E_CANTOPENFILE: Unable to open file



CantOpenObj

H5E_CANTOPENOBJ: Can’t open object



CantOperate

H5E_CANTOPERATE: Can’t operate on object



CantPack

H5E_CANTPACK: Can’t pack messages



CantPin

H5E_CANTPIN: Unable to pin cache entry



CantProtect

H5E_CANTPROTECT: Unable to protect metadata



CantPut

H5E_CANTPUT: Can’t put value



CantRecv

H5E_CANTRECV: Can’t receive data



CantRedistribute

H5E_CANTREDISTRIBUTE: Unable to redistribute records



CantRegister

H5E_CANTREGISTER: Unable to register new ID



CantRelease

H5E_CANTRELEASE: Unable to release object



CantRemove

H5E_CANTREMOVE: Unable to remove object



CantRename

H5E_CANTRENAME: Unable to rename object



CantReset

H5E_CANTRESET: Can’t reset object



CantResize

H5E_CANTRESIZE: Unable to resize a metadata cache entry



CantRestore

H5E_CANTRESTORE: Can’t restore condition



CantRevive

H5E_CANTREVIVE: Can’t revive object



CantSelect

H5E_CANTSELECT: Can’t select hyperslab



CantSerialize

H5E_CANTSERIALIZE: Unable to serialize data from cache



CantSet

H5E_CANTSET: Can’t set value



CantShrink

H5E_CANTSHRINK: Can’t shrink container



CantSort

H5E_CANTSORT: Can’t sort objects



CantSplit

H5E_CANTSPLIT: Unable to split node



CantSwap

H5E_CANTSWAP: Unable to swap records



CantTag

H5E_CANTTAG: Unable to tag metadata in the cache



CantUncork

H5E_CANTUNCORK: Unable to uncork an object



CantUndepend

H5E_CANTUNDEPEND: Unable to destroy a flush dependency



CantUnlock

H5E_CANTUNLOCK: Unable to unlock object



CantUnlockFile

H5E_CANTUNLOCKFILE: Unable to unlock file



CantUnpin

H5E_CANTUNPIN: Unable to un-pin cache entry



CantUnprotect

H5E_CANTUNPROTECT: Unable to unprotect metadata



CantUnserialize

H5E_CANTUNSERIALIZE: Unable to mark metadata as unserialized



CantUpdate

H5E_CANTUPDATE: Can’t update object



CantWait

H5E_CANTWAIT: Can’t wait on operation



CloseError

H5E_CLOSEERROR: Close failed



CompLen

H5E_COMPLEN: Name component is too long



DupClass

H5E_DUPCLASS: Duplicate class name in parent class



Exists

H5E_EXISTS: Object already exists



Fcntl

H5E_FCNTL: File control (fcntl) failed



FileExists

H5E_FILEEXISTS: File already exists



FileOpen

H5E_FILEOPEN: File already open



InconsistentState

H5E_INCONSISTENTSTATE: Internal states are inconsistent



LinkCount

H5E_LINKCOUNT: Bad object header link count



Logging

H5E_LOGGING (H5E_LOGFAIL in older HDF5): Failure in the cache logging framework



Mount

H5E_MOUNT: File mount error



Mpi

H5E_MPI: Some MPI function failed



MpiErrStr

H5E_MPIERRSTR: MPI Error String

H5E_NLINKS: Too many soft links in path



NoEncoder

H5E_NOENCODER: Filter present but encoding disabled



NoFilter

H5E_NOFILTER: Requested filter is not available



NoIds

H5E_NOIDS: Out of IDs for group



NoIndependent

H5E_NO_INDEPENDENT: Can’t perform independent IO



NoSpace

H5E_NOSPACE: No space available for allocation



NoneMinor

H5E_NONE_MINOR: No error



NotCached

H5E_NOTCACHED: Metadata not currently cached



NotFound

H5E_NOTFOUND: Object not found



NotHdf5

H5E_NOTHDF5: Not an HDF5 file



NotRegistered

H5E_NOTREGISTERED: Link class not registered



ObjOpen

H5E_OBJOPEN: Object is already open



OpenError

H5E_OPENERROR: Can’t open directory or file



Overflow

H5E_OVERFLOW: Address overflowed



Path

H5E_PATH: Problem with path to object



Protect

H5E_PROTECT: Protected metadata error



ReadError

H5E_READERROR: Read failed



SeekError

H5E_SEEKERROR: Seek failed



SetDisallowed

H5E_SETDISALLOWED: Disallowed operation



SetLocal

H5E_SETLOCAL: Error from filter ‘set local’ callback



SysErrStr

H5E_SYSERRSTR: System error message



System

H5E_SYSTEM: Internal error detected



Traverse

H5E_TRAVERSE: Link traversal failure



Truncated

H5E_TRUNCATED: File has been truncated



Uninitialized

H5E_UNINITIALIZED: Information is uinitialized



Unmount

H5E_UNMOUNT: File unmount error



Unsupported

H5E_UNSUPPORTED: Feature is unsupported



Version

H5E_VERSION: Wrong version number



WriteError

H5E_WRITEERROR: Write failed



Other(hid_t)

A code reported by HDF5 that this crate does not know.

The raw message id is only valid for the lifetime of the process.

Implementations

Source

impl MinorErrorCode

pub fn from_id(id: hid_t) -> Self

Resolves a raw HDF5 message id, or Other if unknown.

pub fn name(self) -> Option<&'static str>

The C identifier, e.g. "H5E_CANTOPENFILE", as spelled by the linked HDF5.

None only for Other.

pub fn description(self) -> Option<&'static str>

The description HDF5 documents for this code, as worded by the linked HDF5.

None only for Other.

pub fn all() -> &'static [Self]

Every code this crate knows, including any the linked HDF5 cannot report.